==> stable-5.1.zip: openclonk/src/res/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by engine.rc
//
#define IDB_BRUSH                       1000
#define IDB_BRUSH2                      1001
#define IDB_CURSOR                      1002
#define IDB_CURSOR2                     1003
#define IDB_DYNAMIC                     1004
#define IDB_EXACT                       1005
#define IDB_FILL                        1006
#define IDB_FILL2                       1007
#define IDB_HALT                        1008
#define IDB_HALT2                       1009
#define IDB_IFT                         1010
#define IDB_LINE                        1011
#define IDB_LINE2                       1012
#define IDB_MOUSE                       1013
#define IDB_MOUSE2                      1014
#define IDB_NOIFT                       1015
#define IDB_PICKER                      1016
#define IDB_PICKER2                     1017
#define IDB_PLAY                        1018
#define IDB_PLAY2                       1019
#define IDB_RECT                        1020
#define IDB_RECT2                       1021
#define IDB_STATIC                      1022
#define IDC_BUTTONBRUSH                 2000
#define IDC_BUTTONFILL                  2001
#define IDC_BUTTONHALT                  2002
#define IDC_BUTTONIFT                   2003
#define IDC_BUTTONLINE                  2004
#define IDC_BUTTONMODEDRAW              2005
#define IDC_BUTTONMODEDYNAMIC           2006
#define IDC_BUTTONMODEEDIT              2007
#define IDC_BUTTONMODEEXACT             2008
#define IDC_BUTTONMODEPLAY              2009
#define IDC_BUTTONMODESTATIC            2010
#define IDC_BUTTONNOIFT                 2011
#define IDC_BUTTONPICKER                2012
#define IDC_BUTTONPLAY                  2013
#define IDC_BUTTONRECT                  2014
#define IDC_BUTTONRELOADDEF             2015
#define IDC_COMBOINPUT                  2016
#define IDC_COMBOMATERIAL               2017
#define IDC_COMBOTEXTURE                2018
#define IDC_EDITDATA                    2019
#define IDC_EDITOUTPUT                  2020
#define IDC_PREVIEW                     2021
#define IDC_SLIDERGRADE                 2022
#define IDC_STATICCURSOR                2023
#define IDC_STATICFRAME                 2024
#define IDC_STATICMATERIAL              2025
#define IDC_STATICSCRIPT                2026
#define IDC_STATICTEXTURE               2027
#define IDC_STATICTIME                  2028
#define IDD_COMPONENT                   3000
#define IDD_CONSOLE                     3001
#define IDD_PROPERTIES                  3002
#define IDD_TOOLS                       3003
#define IDI_00_C4X                      4000
#define IDI_01_C4S                      4001
#define IDI_02_C4G                      4002
#define IDI_03_C4F                      4003
#define IDI_04_C4P                      4004
#define IDI_05_C4X                      4005
#define IDI_06_C4D                      4006
#define IDI_07_C4I                      4007
#define IDI_08_C4M                      4008
#define IDI_09_C4B                      4009
#define IDI_10_C4V                      4010
#define IDI_11_C4L                      4011
#define IDI_12_C4K                      4012
#define IDI_13_C4U                      4013
#define IDM_COMPONENTS_INFO             5000
#define IDM_COMPONENTS_SCRIPT           5001
#define IDM_COMPONENTS_TITLE            5002
#define IDM_FILE_CLOSE                  5003
#define IDM_FILE_OPEN                   5004
#define IDM_FILE_OPENWPLRS              5005
#define IDM_FILE_QUIT                   5006
#define IDM_FILE_SAVE                   5007
#define IDM_FILE_SAVEAS                 5008
#define IDM_FILE_SAVEGAME               5009
#define IDM_FILE_SAVEGAMEAS             5010
#define IDM_HELP_ABOUT                  5011
#define IDM_PLAYER_JOIN                 5012
#define IDM_VIEWPORT_CONTENTS           5013
#define IDM_VIEWPORT_DELETE             5014
#define IDM_VIEWPORT_DUPLICATE          5015
#define IDM_VIEWPORT_NEW                5016
#define IDM_VIEWPORT_PROPERTIES         5017
#define IDR_CONSOLEMENU                 6000
#define IDR_CONTEXTMENUS                6001
#define IDM_FILE_RECORD                 40041
#define IDR_HGREVISION                  7000

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        180
#define _APS_NEXT_COMMAND_VALUE         40043
#define _APS_NEXT_CONTROL_VALUE         1045
#define _APS_NEXT_SYMED_VALUE           123
#endif
#endif

==> stable-5.2.zip: openclonk/src/res/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by engine.rc
//
#define IDB_BRUSH                       1000
#define IDB_BRUSH2                      1001
#define IDB_CURSOR                      1002
#define IDB_CURSOR2                     1003
#define IDB_DYNAMIC                     1004
#define IDB_EXACT                       1005
#define IDB_FILL                        1006
#define IDB_FILL2                       1007
#define IDB_HALT                        1008
#define IDB_HALT2                       1009
#define IDB_IFT                         1010
#define IDB_LINE                        1011
#define IDB_LINE2                       1012
#define IDB_MOUSE                       1013
#define IDB_MOUSE2                      1014
#define IDB_NOIFT                       1015
#define IDB_PICKER                      1016
#define IDB_PICKER2                     1017
#define IDB_PLAY                        1018
#define IDB_PLAY2                       1019
#define IDB_RECT                        1020
#define IDB_RECT2                       1021
#define IDB_STATIC                      1022
#define IDC_BUTTONBRUSH                 2000
#define IDC_BUTTONFILL                  2001
#define IDC_BUTTONHALT                  2002
#define IDC_BUTTONIFT                   2003
#define IDC_BUTTONLINE                  2004
#define IDC_BUTTONMODEDRAW              2005
#define IDC_BUTTONMODEDYNAMIC           2006
#define IDC_BUTTONMODEEDIT              2007
#define IDC_BUTTONMODEEXACT             2008
#define IDC_BUTTONMODEPLAY              2009
#define IDC_BUTTONMODESTATIC            2010
#define IDC_BUTTONNOIFT                 2011
#define IDC_BUTTONPICKER                2012
#define IDC_BUTTONPLAY                  2013
#define IDC_BUTTONRECT                  2014
#define IDC_BUTTONRELOADDEF             2015
#define IDC_COMBOINPUT                  2016
#define IDC_COMBOMATERIAL               2017
#define IDC_COMBOTEXTURE                2018
#define IDC_EDITDATA                    2019
#define IDC_EDITOUTPUT                  2020
#define IDC_PREVIEW                     2021
#define IDC_SLIDERGRADE                 2022
#define IDC_STATICCURSOR                2023
#define IDC_STATICFRAME                 2024
#define IDC_STATICMATERIAL              2025
#define IDC_STATICSCRIPT                2026
#define IDC_STATICTEXTURE               2027
#define IDC_STATICTIME                  2028
#define IDD_COMPONENT                   3000
#define IDD_CONSOLE                     3001
#define IDD_PROPERTIES                  3002
#define IDD_TOOLS                       3003
#define IDI_00_C4X                      4000
#define IDI_01_OCS                      4001
#define IDI_02_OCG                      4002
#define IDI_03_OCF                      4003
#define IDI_04_OCP                      4004
#define IDI_06_OCD                      4006
#define IDI_07_OCI                      4007
#define IDI_08_OCM                      4008
#define IDI_09_OCB                      4009
#define IDI_10_OCV                      4010
#define IDI_11_OCL                      4011
#define IDI_13_OCU                      4013
#define IDM_FILE_CLOSE                  5003
#define IDM_FILE_OPEN                   5004
#define IDM_FILE_OPENWPLRS              5005
#define IDM_FILE_QUIT                   5006
#define IDM_FILE_SAVE                   5007
#define IDM_FILE_SAVEAS                 5008
#define IDM_FILE_SAVEGAMEAS             5010
#define IDM_HELP_ABOUT                  5011
#define IDM_PLAYER_JOIN                 5012
#define IDM_VIEWPORT_CONTENTS           5013
#define IDM_VIEWPORT_DELETE             5014
#define IDM_VIEWPORT_DUPLICATE          5015
#define IDM_VIEWPORT_NEW                5016
#define IDR_CONSOLEMENU                 6000
#define IDR_CONTEXTMENUS                6001
#define IDM_FILE_RECORD                 40041
#define IDR_HGREVISION                  7000

// Next default values for new objects
//
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        180
#define _APS_NEXT_COMMAND_VALUE         40043
#define _APS_NEXT_CONTROL_VALUE         1045
#define _APS_NEXT_SYMED_VALUE           123
#endif
#endif
